@@ -15,6 +15,7 @@ from typing import Optional
 from typing import TypeVar
 from typing import Union
 
+from .exceptions import JSONPathIndexError
 from .exceptions import JSONPathTypeError
 from .match import JSONPathMatch
 
@@ -113,6 +114,9 @@ class IndexSelector(JSONPathSelector):
         token: Token,
         index: int,
     ) -> None:
+        if index < env.min_int_index or index > env.max_int_index:
+            raise JSONPathIndexError("index out of range", token=token)
+
         super().__init__(env=env, token=token)
         self.index = index
         self._as_key = str(self.index)
@@ -201,6 +205,7 @@ class SliceSelector(JSONPathSelector):
         step: Optional[int] = None,
     ) -> None:
         super().__init__(env=env, token=token)
+        self._check_range(start, stop, step)
         self.slice = slice(start, stop, step)
 
     def __str__(self) -> str:
@@ -209,6 +214,13 @@ class SliceSelector(JSONPathSelector):
         step = self.slice.step if self.slice.step is not None else "1"
         return f"[{start}:{stop}:{step}]"
 
+    def _check_range(self, *indices: Optional[int]) -> None:
+        for i in indices:
+            if i is not None and (
+                i < self.env.min_int_index or i > self.env.max_int_index
+            ):
+                raise JSONPathIndexError("index out of range")
+
     def _normalized_index(self, obj: Sequence[object], index: int) -> int:
         if index < 0 and len(obj) >= abs(index):
             return len(obj) + index
@@ -396,7 +408,9 @@ class ListSelector(JSONPathSelector):
         *,
         env: JSONPathEnvironment,
         token: Token,
-        items: List[Union[SliceSelector, IndexSelector, PropertySelector]],
+        items: List[
+            Union[SliceSelector, IndexSelector, PropertySelector, WildSelector]
+        ],
     ) -> None:
         super().__init__(env=env, token=token)
         self.items = items
@@ -411,6 +425,8 @@ class ListSelector(JSONPathSelector):
                 buf.append(f"{start}:{stop}:{step}")
             elif isinstance(item, PropertySelector):
                 buf.append(f"'{item.name}'")
+            elif isinstance(item, WildSelector):
+                buf.append("*")
             else:
                 buf.append(str(item.index))
         return f"[{', '.join(buf)}]"
