@@ -63,7 +63,6 @@ FILTER_SELECTOR_DATA = {
     "e": "f",
 }
 
-# TODO: update with examples from version 12
 
 TEST_CASES = [
     Case(description="root", path="$", data={"k": "v"}, want=[{"k": "v"}]),
@@ -97,12 +96,12 @@ TEST_CASES = [
         data={"o": {"j": 1, "k": 2}, "a": [5, 3]},
         want=[1, 2],
     ),
-    # Case(
-    #     description="wildcard selector - double wild",
-    #     path="$.o[*, *]",
-    #     data={"o": {"j": 1, "k": 2}, "a": [5, 3]},
-    #     want=[1, 2, 1, 2],
-    # ),
+    Case(
+        description="wildcard selector - double wild",
+        path="$.o[*, *]",
+        data={"o": {"j": 1, "k": 2}, "a": [5, 3]},
+        want=[1, 2, 1, 2],
+    ),
     Case(
         description="wildcard selector - dot property wild",
         path="$.a[*]",
@@ -127,6 +126,12 @@ TEST_CASES = [
         data=["a", "b", "c", "d", "e", "f", "g"],
         want=["b", "c"],
     ),
+    Case(
+        description="array slice selector - slice with no end index",
+        path="$[5:]",
+        data=["a", "b", "c", "d", "e", "f", "g"],
+        want=["f", "g"],
+    ),
     Case(
         description="array slice selector - slice with negative step",
         path="$[5:1:-2]",
@@ -166,30 +171,30 @@ TEST_CASES = [
             {"p": 1, "q": 2, "r": 3, "s": 5, "t": {"u": 6}},
         ],
     ),
-    # Case(
-    #     description="filter selector - Nested filters",
-    #     path="$[?(@[?(@.b)])]	",
-    #     data=FILTER_SELECTOR_DATA,
-    #     want=[[3, 5, 1, 2, 4, 6, {"b": "j"}, {"b": "k"}, {"b": {}}, {"b": "kilo"}]],
-    # ),
+    Case(
+        description="filter selector - Nested filters",
+        path="$[?(@[?(@.b)])]	",
+        data=FILTER_SELECTOR_DATA,
+        want=[[3, 5, 1, 2, 4, 6, {"b": "j"}, {"b": "k"}, {"b": {}}, {"b": "kilo"}]],
+    ),
     Case(
         description="filter selector - Array value logical OR",
         path='$.a[?(@<2 || @.b == "k")]',
         data=FILTER_SELECTOR_DATA,
         want=[1, {"b": "k"}],
     ),
-    # Case(
-    #     description="filter selector - Array value regular expression match",
-    #     path='$.a[?match(@.b, "[jk]")]',
-    #     data=FILTER_SELECTOR_DATA,
-    #     want=[{"b": "j"}, {"b": "k"}],
-    # ),
-    # Case(
-    #     description="filter selector - Array value regular expression search",
-    #     path='$.a[?search(@.b, "[jk]")]',
-    #     data=FILTER_SELECTOR_DATA,
-    #     want=[{"b": "j"}, {"b": "k"}, {"b": "kilo"}],
-    # ),
+    Case(
+        description="filter selector - Array value regular expression match",
+        path='$.a[?match(@.b, "[jk]")]',
+        data=FILTER_SELECTOR_DATA,
+        want=[{"b": "j"}, {"b": "k"}],
+    ),
+    Case(
+        description="filter selector - Array value regular expression search",
+        path='$.a[?search(@.b, "[jk]")]',
+        data=FILTER_SELECTOR_DATA,
+        want=[{"b": "j"}, {"b": "k"}, {"b": "kilo"}],
+    ),
     Case(
         description="filter selector - Object value logical AND",
         path="$.o[?(@>1 && @<4)]",
